@@ -1,7 +1,7 @@
 /*
  *  messagewin.cpp  -  displays an alarm message
  *  Program:  kalarm
- *  Copyright © 2001-2009 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2010 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -1361,7 +1361,7 @@ void MessageWin::stopAudio(bool wait)
 {
 	kDebug();
 	if (mAudioThread)
-		mAudioThread->stop();
+		mAudioThread->stop(wait);
 }
 
 /******************************************************************************
