@@ -1,8 +1,6 @@
 /*
-    knfilterconfigwidget.cpp
-
     KNode, the KDE newsreader
-    Copyright (c) 1999-2001 the KNode authors.
+    Copyright (c) 1999-2005 the KNode authors.
     See file AUTHORS for details
 
     This program is free software; you can redistribute it and/or modify
@@ -14,8 +12,9 @@
     Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
-#include <qlayout.h>
-#include <qlabel.h>
+#include <QLabel>
+//Added by qt3to4:
+#include <QVBoxLayout>
 
 #include <klocale.h>
 
@@ -24,16 +23,19 @@
 #include "knrangefilter.h"
 #include "knfilterconfigwidget.h"
 
+using namespace KNode;
 
-KNFilterConfigWidget::KNFilterConfigWidget(QWidget *parent, const char *name ) :
-  QTabWidget(parent,name)
+KNFilterConfigWidget::KNFilterConfigWidget( QWidget *parent ) :
+  QTabWidget( parent )
 {
   QWidget *sf, *idW, *add;
   sf=new QWidget(this);
-  QVBoxLayout *sfL=new QVBoxLayout(sf, 8,5);
-  subject=new KNStringFilterWidget(i18n("Subject"), sf);
+  QVBoxLayout *sfL=new QVBoxLayout(sf);
+  sfL->setSpacing(5);
+  sfL->setMargin(8);
+  subject = new StringFilterWidget( i18n("Subject"), sf );
   sfL->addWidget(subject);
-  from=new KNStringFilterWidget(i18n("From"), sf);
+  from = new StringFilterWidget( i18n("From"), sf );
   sfL->addWidget(from);
   QLabel *l = new QLabel(i18n("The following placeholders are supported:\n%MYNAME=own name, %MYEMAIL=own email address"),sf);
   sfL->addWidget(l);
@@ -41,24 +43,28 @@ KNFilterConfigWidget::KNFilterConfigWidget(QWidget *parent, const char *name ) :
   addTab(sf, i18n("Subject && &From"));
 
   idW=new QWidget(this);
-  QVBoxLayout *idL=new QVBoxLayout(idW, 8,5);
-  messageId=new KNStringFilterWidget(i18n("Message-ID"), idW);
+  QVBoxLayout *idL=new QVBoxLayout(idW);
+  idL->setSpacing(5);
+  idL->setMargin(8);
+  messageId = new StringFilterWidget( i18n("Message-ID"), idW );
   idL->addWidget(messageId);
-  references=new KNStringFilterWidget(i18n("References"), idW);
+  references = new StringFilterWidget( i18n("References"), idW );
   idL->addWidget(references);
   idL->addStretch(1);
   addTab(idW, i18n("M&essage-IDs"));
 
-  status=new KNStatusFilterWidget(this);
+  status = new StatusFilterWidget( this );
   addTab(status, i18n("&Status"));
 
   add=new QWidget(this);
-  QVBoxLayout *addL=new QVBoxLayout(add, 8,5);
-  score=new KNRangeFilterWidget(i18n("Score"), -99999, 99999, add);
+  QVBoxLayout *addL=new QVBoxLayout(add);
+  addL->setSpacing(5);
+  addL->setMargin(8);
+  score = new RangeFilterWidget( i18n("Score"), -99999, 99999, add );
   addL->addWidget(score);
-  age=new KNRangeFilterWidget(i18n("Age"), 0, 999, add, i18n(" days"));
+  age = new RangeFilterWidget( i18n("Age"), 0, 999, add, i18n(" days") );
   addL->addWidget(age);
-  lines=new KNRangeFilterWidget(i18n("Lines"), 0, 99999, add);
+  lines = new RangeFilterWidget( i18n("Lines"), 0, 99999, add );
   addL->addWidget(lines);
   addL->addStretch(1);
   addTab(add, i18n("&Additional"));
