@@ -317,10 +317,10 @@ QDate CalendarView::activeDate( bool fallbackToToday )
       return curView->selectionStart().date();
     }
 
-    // Try the view's selectedDates()
-    if ( !curView->selectedDates().isEmpty() ) {
-      if ( curView->selectedDates().first().isValid() ) {
-        return curView->selectedDates().first();
+    // Try the view's selectedIncidenceDates()
+    if ( !curView->selectedIncidenceDates().isEmpty() ) {
+      if ( curView->selectedIncidenceDates().first().isValid() ) {
+        return curView->selectedIncidenceDates().first();
       }
     }
   }
@@ -333,6 +333,19 @@ QDate CalendarView::activeDate( bool fallbackToToday )
   }
 }
 
+QDate CalendarView::activeIncidenceDate()
+{
+  KOrg::BaseView *curView = mViewManager->currentView();
+  if ( curView ) {
+    DateList dates = curView->selectedIncidenceDates();
+    if ( !dates.isEmpty() ) {
+      return dates.first();
+    }
+  }
+
+  return QDate();
+}
+
 QDate CalendarView::startDate()
 {
   DateList dates = mDateNavigator->selectedDates();
@@ -870,16 +883,15 @@ void CalendarView::edit_paste()
     if ( !aView->selectedIsAllDay() ) {
       time = aView->selectionStart().time();
     }
-  } else if ( curView == mView && !mView->selectedDates().isEmpty() ) {
-    date = mView->selectedDates().first();
-  } else {
-    // default to the selected date from the navigator
-    if ( !mDateNavigator->selectedDates().isEmpty() ) {
+  } else if ( curView == mView && mView->selectionStart().isValid() ) {
+    date = mView->selectionStart().date();
+  } else if ( !mDateNavigator->selectedDates().isEmpty() &&
+              curView->supportsDateNavigation() ) {
+      // default to the selected date from the navigator
       date = mDateNavigator->selectedDates().first();
-    }
   }
 
-  if ( !date.isValid() ) {
+  if ( !date.isValid() && curView->supportsDateNavigation() ) {
     KMessageBox::sorry(
       this,
       i18n( "Paste failed: unable to determine a valid target date." ) );
@@ -931,17 +943,16 @@ void CalendarView::edit_options()
 void CalendarView::dateTimesForNewEvent( QDateTime &startDt, QDateTime &endDt,
                                          bool &allDay )
 {
-  if ( !startDt.isValid() ) {
-    startDt.setDate( activeDate() );
+  mViewManager->currentView()->eventDurationHint( startDt, endDt, allDay );
+
+  if ( !startDt.isValid() || !endDt.isValid() ) {
+    startDt.setDate( activeDate( true ) );
     startDt.setTime( KOPrefs::instance()->mStartTime.time() );
-  }
-  if ( !endDt.isValid() ) {
     int addSecs =
       ( KOPrefs::instance()->mDefaultDuration.time().hour() * 3600 ) +
       ( KOPrefs::instance()->mDefaultDuration.time().minute() * 60 );
     endDt = startDt.addSecs( addSecs );
   }
-  mViewManager->currentView()->eventDurationHint( startDt, endDt, allDay );
 }
 
 KOEventEditor *CalendarView::newEventEditor( const QDateTime &startDtParam,
@@ -973,12 +984,18 @@ void CalendarView::newEvent()
 void CalendarView::newEvent( const QDate &dt )
 {
   QDateTime startDt( dt, KOPrefs::instance()->mStartTime.time() );
-  return newEvent( QDateTime( dt ), QDateTime() );
+  QTime duration = KOPrefs::instance()->defaultDuration().time();
+  QTime time = startDt.time();
+  time = time.addSecs( duration.hour()*3600 + duration.minute() * 60 +  duration.second() );
+  QDateTime endDt( startDt );
+  endDt.setTime( time );
+
+  newEvent( startDt, endDt );
 }
 
 void CalendarView::newEvent( const QDateTime &startDt )
 {
-  return newEvent( startDt, QDateTime() );
+  newEvent( startDt, startDt );
 }
 
 void CalendarView::newEvent( const QDateTime &startDt, const QDateTime &endDt, bool allDay )
@@ -1237,6 +1254,7 @@ void CalendarView::toggleAlarm( Incidence *incidence )
     Alarm *alm = incidence->newAlarm();
     alm->setType( Alarm::Display );
     alm->setEnabled( true );
+    alm->setStartOffset( Duration( 60 ) ); //Set to 1 minute
   }
   mChanger->changeIncidence( oldincidence, incidence, KOGlobals::ALARM_MODIFIED, this );
   mChanger->endChange( incidence );
@@ -2322,7 +2340,7 @@ bool CalendarView::editIncidence( Incidence *incidence, bool isCounter )
   connectIncidenceEditor( incidenceEditor );
 
   mDialogList.insert( incidence, incidenceEditor );
-  incidenceEditor->editIncidence( incidence, activeDate(), mCalendar );
+  incidenceEditor->editIncidence( incidence, activeIncidenceDate(), mCalendar );
   incidenceEditor->show();
   return true;
 }
