@@ -84,8 +84,9 @@ KOEventPopupMenu::KOEventPopupMenu()
   mTodoOnlyItems.append( addAction( KOGlobals::self()->smallIcon( "task-complete" ),
                                     i18n( "Togg&le To-do Completed" ),
                                     this, SLOT(toggleTodoCompleted()) ) );
-  mEditOnlyItems.append( addAction( QIcon( KOGlobals::self()->smallIcon( "appointment-reminder" ) ),
-                                    i18n( "&Toggle Reminder" ), this, SLOT(toggleAlarm())) );
+  mToggleReminder = addAction( QIcon( KOGlobals::self()->smallIcon( "appointment-reminder" ) ),
+                                    i18n( "&Toggle Reminder" ), this, SLOT(toggleAlarm()));
+  mEditOnlyItems.append( mToggleReminder );
   //------------------------------------------------------------------------
   mRecurrenceItems.append( addSeparator() );
   mDissociateOccurrences = addAction( i18n( "&Dissociate From Recurrence..." ),
@@ -114,8 +115,7 @@ void KOEventPopupMenu::showIncidencePopup( Calendar *cal, Incidence *incidence,
     delete mMoveToCalendarMenu;
     mMoveToCalendarMenu = 0;
   }
-
-  if ( mCurrentIncidence && qd.isValid() ) {
+  if ( mCurrentIncidence /*&& qd.isValid()*/ ) {
 
     if ( mCurrentIncidence->recurs() ) {
       KDateTime thisDateTime( qd, KOPrefs::instance()->timeSpec() );
@@ -133,6 +133,8 @@ void KOEventPopupMenu::showIncidencePopup( Calendar *cal, Incidence *incidence,
     for ( it = mEditOnlyItems.begin(); it != mEditOnlyItems.end(); ++it ) {
       (*it)->setEnabled( !mCurrentIncidence->isReadOnly() );
     }
+    mToggleReminder->setVisible( ( mCurrentIncidence->type() != "Journal" ) );
+
     for ( it = mRecurrenceItems.begin(); it != mRecurrenceItems.end(); ++it ) {
       (*it)->setVisible( mCurrentIncidence->recurs() );
     }
@@ -174,34 +176,29 @@ void KOEventPopupMenu::popupEdit()
   }
 }
 
-void KOEventPopupMenu::print()
+void KOEventPopupMenu::print( bool preview )
 {
 #ifndef KORG_NOPRINTER
   KOCoreHelper helper;
-  CalPrinter printer( this, mCalendar, &helper );
+  CalPrinter printer( this, mCalendar, &helper, true );
   connect( this, SIGNAL(configChanged()), &printer, SLOT(updateConfig()) );
 
   Incidence::List selectedIncidences;
   selectedIncidences.append( mCurrentIncidence );
 
   printer.print( KOrg::CalPrinterBase::Incidence,
-                 mCurrentDate, mCurrentDate, selectedIncidences, false );
+                 mCurrentDate, mCurrentDate, selectedIncidences, preview );
 #endif
 }
 
+void KOEventPopupMenu::print()
+{
+  print( false );
+}
+
 void KOEventPopupMenu::printPreview()
 {
-#ifndef KORG_NOPRINTER
-  KOCoreHelper helper;
-  CalPrinter printer( this, mCalendar, &helper );
-  connect( this, SIGNAL(configChanged()), &printer, SLOT(updateConfig()) );
-
-  Incidence::List selectedIncidences;
-  selectedIncidences.append( mCurrentIncidence );
-
-  printer.print( KOrg::CalPrinterBase::Incidence,
-                 mCurrentDate, mCurrentDate, selectedIncidences, true );
-#endif
+  print( true );
 }
 
 void KOEventPopupMenu::popupDelete()
