@@ -23,17 +23,18 @@
 #define KABC_RESOURCEGROUPDAV_H
 
 #include "kabc_resourcegroupwarebase.h"
-#include <kdepimmacros.h>
+#include "groupdav_export.h"
 
 namespace KABC {
 
-class KDE_EXPORT ResourceGroupDav : public ResourceGroupwareBase
+class KABC_GROUPDAV_EXPORT ResourceGroupDav : public ResourceGroupwareBase
 {
   Q_OBJECT
 
   public:
-    ResourceGroupDav( const KConfig * );
-//     ResourceGroupDav( const KURL &url,
+    ResourceGroupDav();
+    explicit ResourceGroupDav( const KConfigGroup &group );
+//     ResourceGroupDav( const KUrl &url,
 //             const QString &user, const QString &password );
   protected:
     void init();
