@@ -175,9 +175,9 @@ bool ResourceKolab::loadSubResource( const QString& subResource,
   const QString labelTxt = !strcmp(mimetype, "application/x-vnd.kolab.task") ? i18n( "Loading tasks..." )
                            : !strcmp(mimetype, "application/x-vnd.kolab.journal") ? i18n( "Loading journals..." )
                            : i18n( "Loading events..." );
-  const bool useProgress = qApp && qApp->type() != QApplication::Tty && count > mProgressDialogIncidenceLimit;
 //TODO port me kde4
 #if 0
+  const bool useProgress = qApp && qApp->type() != QApplication::Tty && count > mProgressDialogIncidenceLimit;
   //  if ( useProgress )
   //  (void)::Observer::self(); // ensure kio_uiserver is running
   int progressId = 0;
@@ -490,7 +490,7 @@ bool ResourceKolab::sendKMailUpdate( KCal::IncidenceBase* incidencebase, const Q
           iTIPRequest );
     }
   } else {
-    kWarning(5006) <<"Can't happen: unhandled type=" << type;
+    kWarning(5650) <<"Can't happen: unhandled type=" << type;
   }
 
 //  kDebug() <<"Data string:" << data;
@@ -592,11 +592,13 @@ bool ResourceKolab::addIncidence( KCal::Incidence* incidence, const QString& _su
       text += "<br>";
       if ( incidence->type() == "Event" ) {
         Event* event = static_cast<Event*>( incidence );
-        if ( event->hasEndDate() )
-          if ( !event->recurrence()->allDay() )
+        if ( event->hasEndDate() ) {
+          if ( !event->recurrence()->allDay() ) {
             text += i18n( "<b>End:</b> %1, %2", event->dtEndDateStr(), event->dtEndTimeStr() );
-          else
+          } else {
             text += i18n( "<b>End:</b> %1", event->dtEndDateStr() );
+          }
+        }
         text += "<br>";
       }
       subResource = findWritableResource( *map, text );
@@ -958,7 +960,7 @@ void ResourceKolab::fromKMailRefresh( const QString& type,
   else if ( type == "Journal" )
     loadAllJournals();
   else
-    kWarning(5006) <<"KCal Kolab resource: fromKMailRefresh: unknown type" << type;
+    kWarning(5650) <<"KCal Kolab resource: fromKMailRefresh: unknown type" << type;
   mResourceChangedTimer.start( 100 );
 }
 
