@@ -110,7 +110,19 @@ protected:
   // Read all known fields from this ical todo
   void setFields( const KCal::Todo* );
 
+  // This sets the priority of this task by looking at mKolabPriorityFromDom and
+  // mKCalPriorityFromDom.
+  void decideAndSetPriority();
+
+  // This is the KCal priority, not the Kolab priority.
+  // See kcalPriorityToKolab() and kolabPrioritytoKCal().
   int mPriority;
+
+  // Those priority values are the raw values read by loadAttribute().
+  // They will be converted later in decideAndSetPriority().
+  int mKolabPriorityFromDom;
+  int mKCalPriorityFromDom;
+
   int mPercentCompleted;
   KCal::Incidence::Status mStatus;
   QString mParent;
