@@ -113,7 +113,7 @@ bool ResourceKolab::loadSubResource( const QString& subResource,
   KMail::SernumDataPair::List lst;
   if( !kmailIncidences( lst, mimetype, subResource, 0, count ) ) {
     kError(5500) <<"Communication problem in"
-                  << "ResourceKolab::getIncidenceList()\n";
+                  << "ResourceKolab::getIncidenceList()";
     return false;
   }
 
@@ -185,6 +185,11 @@ KCal::Journal* ResourceKolab::addNote( const QString& data, const QString& subre
     else
       delete journal;
   }
+  else if ( journal && mUidMap.contains( journal->uid() ) )
+  {
+    //For debugging
+    kDebug( 5500 ) << "mUidMap already contains" << journal->uid();
+  }
   return 0;
 }
 
@@ -192,7 +197,6 @@ bool ResourceKolab::addNote( KCal::Journal* journal,
                              const QString& subresource, quint32 sernum )
 {
   kDebug(5500) <<"ResourceKolab::addNote( KCal::Journal*, '" << subresource <<"'," << sernum <<" )";
-
   journal->registerObserver( this );
 
   // Find out if this note was previously stored in KMail
@@ -202,8 +206,9 @@ bool ResourceKolab::addNote( KCal::Journal* journal,
   QString resource =
     newNote ? findWritableResource( mSubResources ) : subresource;
   if ( resource.isEmpty() ) // canceled
+  {
     return false;
-
+  }
   if ( !mSilent ) {
     QString xml = Note::journalToXML( journal );
     kDebug(5500) <<"XML string:" << xml;
@@ -218,7 +223,6 @@ bool ResourceKolab::addNote( KCal::Journal* journal,
     mUidMap[ journal->uid() ] = StorageReference( resource, sernum );
     return true;
   }
-
   return false;
 }
 
@@ -234,7 +238,6 @@ bool ResourceKolab::deleteNote( KCal::Journal* journal )
                           mUidMap[ uid ].serialNumber() );
   }
   mUidMap.remove( uid );
-  manager()->deleteNote( journal );
   mCalendar.deleteJournal( journal );
   return true;
 }
@@ -323,13 +326,17 @@ void ResourceKolab::fromKMailDelIncidence( const QString& type,
   mSilent = true;
   KCal::Journal* j = mCalendar.journal( uid );
   if( j )
+  {
+    manager()->deleteNote( j );
     deleteNote( j );
+  }
   mSilent = silent;
 }
 
 void ResourceKolab::fromKMailRefresh( const QString& type,
                                       const QString& /*subResource*/ )
 {
+  kDebug(5500) <<"ResourceKolab::fromKMailRefresh(" <<type;
   if ( type == kmailContentsType )
     load(); // ### should call loadSubResource(subResource) probably
 }
@@ -340,6 +347,8 @@ void ResourceKolab::fromKMailAddSubresource( const QString& type,
                                              bool writable,
                                              bool /*alarmRelevant*/ )
 {
+  kDebug(5500) <<"ResourceKolab::fromKMailAddSubresource(" << type <<"," << subResource
+	                            << ")";
   if ( type != kmailContentsType )
     // Not ours
     return;
@@ -360,6 +369,8 @@ void ResourceKolab::fromKMailAddSubresource( const QString& type,
 void ResourceKolab::fromKMailDelSubresource( const QString& type,
                                              const QString& subResource )
 {
+  kDebug(5500) <<"ResourceKolab::fromKMailDelSubresource(" << type <<"," << subResource
+	                  << ")";
   if ( type != configGroupName )
     // Not ours
     return;
