@@ -22,28 +22,30 @@
 #ifndef WEBDAVHANDLER_H
 #define WEBDAVHANDLER_H
 
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qdom.h>
-#include <qdatetime.h>
-#include <kurl.h>
-#include <kdepimmacros.h>
+#include "kgroupware_export.h"
 
-class KDE_EXPORT WebdavHandler
+#include <kurl.h>
+
+#include <QString>
+#include <QStringList>
+#include <qdom.h>
+#include <QDateTime>
+
+class KGROUPWAREDAV_EXPORT WebdavHandler
 {
   public:
     WebdavHandler();
 
-    static KURL toDAV( const KURL& url );
+    static KUrl toDAV( const KUrl& url );
 
 
     static QDomElement addElementNS( QDomDocument &doc, QDomNode &node,
                                      const QString &ns, const QString &tag,
-                                     const QString &value = QString::null );
+                                     const QString &value = QString() );
     static QDomElement addElement( QDomDocument &, QDomNode &,
-                         const QString &tag, const QString &value = QString::null );
+                         const QString &tag, const QString &value = QString() );
     static QDomElement addDavElement( QDomDocument &, QDomNode &,
-                         const QString &tag, const QString &value = QString::null );
+                         const QString &tag, const QString &value = QString() );
 
     static bool extractBool( const QDomElement &node, 
                          const QString &entry, bool &value );
@@ -65,12 +67,18 @@ class KDE_EXPORT WebdavHandler
 
 
     /**
-     * Return the representation of utc time in the time zone indicated by timeZoneId
+     * Return the representation of UTC time in the time zone indicated by timeZoneId
+     *
+     * @param utc UTC time. If its timeSpec() is not Qt::UTC, no conversion is done.
+     * @param timeZoneId time zone name, e.g. Europe/Rekjavik
      */
     static QDateTime utcAsZone( const QDateTime& utc, const QString& timeZoneId );
 
     /**
      * Return the UTC representation of local time in the time zone indicated by timeZoneId 
+     *
+     * @param zone local time. If its timeSpec() is not Qt::LocalTime, no conversion is done.
+     * @param timeZoneId time zone name, e.g. Europe/Rekjavik
      */
     static QDateTime zoneAsUtc( const QDateTime& zone, const QString& timeZoneId );
 };
