@@ -2,7 +2,7 @@
   kscoringeditor.cpp
 
   Copyright (c) 2001 Mathias Waack <mathias@atoll-net.de>
-  Copyright (C) 2005 by Volker Krause <volker.krause@rwth-aachen.de>
+  Copyright (C) 2005 by Volker Krause <vkrause@kde.org>
 
   Author: Mathias Waack <mathias@atoll-net.de>
 
@@ -1061,7 +1061,7 @@ KScoringEditorWidgetDialog::KScoringEditorWidgetDialog( KScoringManager *m,
   : KDialog( p ), manager( m ), ruleName( r )
 {
   setCaption( i18n( "Edit Rule" ) );
-  setButtons( KDialog::Ok|KDialog::Apply|KDialog::Close );
+  setButtons( KDialog::Ok|KDialog::Apply|KDialog::Cancel );
   setDefaultButton( KDialog::Ok );
   setModal( true );
   showButtonSeparator( true );
